from typing import ClassVar, Final
from typing_extensions import deprecated

from docutils import nodes
from docutils.transforms import Transform

__docformat__: Final = "reStructuredText"

@deprecated("docutils.transforms.writer_aux.Compound is deprecated and will be removed in Docutils 0.21 or later.")
class Compound(Transform):
    default_priority: ClassVar[int]
    def __init__(self, document: nodes.document, startnode: nodes.Node | None = None) -> None: ...
    def apply(self) -> None: ...

class Admonitions(Transform):
    default_priority: ClassVar[int]
    def apply(self) -> None: ...



import struct
from _typeshed import SupportsWrite
from collections.abc import Collection, Mapping
from typing import Any

from .fragment import FragmentFD

u8: struct.Struct
u88: struct.Struct
u16: struct.Struct
u1616: struct.Struct
u32: struct.Struct
u64: struct.Struct
s88: struct.Struct
s16: struct.Struct
s1616: struct.Struct
s32: struct.Struct
unity_matrix: bytes
TRACK_ENABLED: int
TRACK_IN_MOVIE: int
TRACK_IN_PREVIEW: int
SELF_CONTAINED: int

def box(box_type: bytes, payload: bytes) -> bytes: ...
def full_box(box_type: bytes, version: int, flags: int, payload: bytes) -> bytes: ...
def write_piff_header(stream: SupportsWrite[bytes], params: Mapping[str, Any]) -> None: ...
def extract_box_data(data: bytes, box_sequence: Collection[bytes]) -> bytes | None: ...

class IsmFD(FragmentFD): ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Protocol Buffers - Google's data interchange format
Copyright 2008 Google Inc.  All rights reserved.
https://developers.google.com/protocol-buffers/

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
copyright notice, this list of conditions and the following disclaimer
in the documentation and/or other materials provided with the
distribution.
    * Neither the name of Google Inc. nor the names of its
contributors may be used to endorse or promote products derived from
this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
"""

import builtins
import typing

import google.protobuf.descriptor
import google.protobuf.message

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SourceContext(google.protobuf.message.Message):
    """`SourceContext` represents information about the source of a
    protobuf element, like the file in which it is defined.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_NAME_FIELD_NUMBER: builtins.int
    file_name: builtins.str
    """The path-qualified name of the .proto file that contained the associated
    protobuf element.  For example: `"google/protobuf/source_context.proto"`.
    """
    def __init__(self, *, file_name: builtins.str | None = ...) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_name", b"file_name"]) -> None: ...

global___SourceContext = SourceContext
